DSDatabaseError class

Custom exception for handling database errors

Implemented types

Constructors

DSDatabaseError(String message, {String code = 'unknown', dynamic originalError})
Constructor for database error

Properties

code → String
Error code
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message
final
originalError → dynamic
Native error object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited